@@ -4,9 +4,10 @@ use ZooKeeper::Constants;
 use Carp;
 use Module::Runtime qw(require_module);
 use Moo;
+use namespace::autoclean;
 use 5.10.1;
 
-our $VERSION = '0.0.20';
+our $VERSION = '0.0.21';
 
 BEGIN {
     if (my $trace_var = $ENV{PERL_ZOOKEEPER_TRACE}) {
@@ -312,7 +313,7 @@ Create a new node with the given path and data. Returns the path for the newly c
         OPTIONAL %extra
             acl
             buffer_length
-            persistent
+            ephemeral
             sequential
             value
 
@@ -321,7 +322,7 @@ Create a new node with the given path and data. Returns the path for the newly c
 around create => sub {
     my ($orig, $self, $path, %extra) = @_;
     my $flags = 0;
-    $flags |= ZOO_EPHEMERAL if !$extra{persistent};
+    $flags |= ZOO_EPHEMERAL if $extra{ephemeral};
     $flags |= ZOO_SEQUENCE  if $extra{sequential};
     return $self->$orig($path, $extra{value}//'', $extra{buffer_length}//$self->buffer_length, $extra{acl}//ZOO_OPEN_ACL_UNSAFE, $flags);
 };
